@@ -1,22 +1,21 @@
 import csv
-import math
 import os
 from typing import (Any, List)
 
 from fedot.core.utils import default_fedot_data_dir
 
 
-def write_composer_history_to_csv(historical_fitness: List[int], historical_chains: List[Any], pop_size: int,
-                                  file='history.csv'):
+def write_composer_history_to_csv(historical_chains: List[Any], file='history.csv'):
     history_dir = os.path.join(default_fedot_data_dir(), 'composing_history')
     file = f'{history_dir}/{file}'
     if not os.path.isdir(history_dir):
         os.mkdir(history_dir)
     write_header_to_csv(file)
-    for i, fitness in enumerate(historical_fitness):
-        gen_num = math.ceil(i / pop_size)
-        historical_chain = historical_chains[i]
-        add_history_to_csv(file, fitness, len(historical_chain.nodes), historical_chain.depth, i, gen_num)
+    i = 0
+    for gen_num, gen_chains in enumerate(historical_chains):
+        for chain in gen_chains:
+            add_history_to_csv(file, chain.fitness, len(chain.nodes), chain.depth, i, gen_num)
+            i += 1
 
 
 def write_header_to_csv(f):
